@@ -35,8 +35,6 @@
 
 static gint   opt_framerate = 30;
 static gchar *opt_fourcc    = "I420";
-static gint   opt_bpp       = 24;
-static gint   opt_depth     = 24;
 
 static GOptionEntry options[] =
 {
@@ -84,6 +82,7 @@ main (int argc, char *argv[])
   GstElement            *capsfilter;
   GstElement            *sink;
   GstCaps               *caps;
+  gchar                 *capsstr;
 
   result = clutter_gst_init_with_args (&argc,
                                        &argv,
@@ -124,7 +123,7 @@ main (int argc, char *argv[])
   /* Video actor */
   actor = g_object_new (CLUTTER_TYPE_ACTOR,
                         "content", g_object_new (CLUTTER_GST_TYPE_CONTENT,
-                                                 "video-sink", sink,
+                                                 "sink", sink,
                                                  NULL),
                         "width", clutter_actor_get_width (stage),
                         "height", clutter_actor_get_height (stage),
@@ -153,7 +152,9 @@ main (int argc, char *argv[])
 
   g_object_set (capsfilter, "caps", caps, NULL);
 
-  g_printf ("%s: [caps] %s\n", __FILE__, gst_caps_to_string (caps));
+  capsstr = gst_caps_to_string (caps);
+  g_printf ("%s: [caps] %s\n", __FILE__, capsstr);
+  g_free (capsstr);
   gst_bin_add_many (GST_BIN (pipeline), src, capsfilter, sink, NULL);
   result = gst_element_link_many (src, capsfilter, sink, NULL);
   if (result == FALSE)
